function [ s ] = rejectClutter( s,  nHistory)
  persistent lastS;
  
  nSamples = length(s);
  if nargin < 2
    nHistory = 1;
  end
  
  %% initialize history matrix
  if isempty(lastS) || ~isequal(size(lastS), [nHistory+1, nSamples]);
    fprintf('>> create new clutter matrix\n');
    lastS = zeros(nHistory+1, nSamples);
  end
  
  %% push s into history matrix
  % circshift old signal "down" by one
  lastS = circshift(lastS, 1, 1);
  % add new signal to top of matrix
  lastS(1, :) = s;
  
  %% reject clutter based last signals
  % copy history matrix
  m = lastS(2:end, :);
  
  % get "reject signals" either as mean of history signals or as weighted
  % sum of history signals...
  reject = mean(m, 1);
  
  s = s - reject;
  
end

